<?php

namespace iwaydev\components\helpers;

use DateTime;
use DateTimeZone;
use DateInterval;

/**
 * Хелпер для работы с датой
 *
 * Class Date
 *
 * @package iwaydev\components\helpers
 */
class Date
{
    /** Формат по-умолчанию */
    const FORMAT = 'Y-m-d H:i:s';
    /** Интервал добавления */
    const INTERVAL_TYPE_ADD = 1;
    /** Интервал убавления */
    const INTERVAL_TYPE_SUB = 2;

    /**
     * Получить дату по интервалу
     *
     * @param string $date Дата
     * @param string $format Формат даты
     * @param integer $intervalType Тип интервала
     * @param integer $intervalValue Значение интервала
     *
     * @return string
     * @throws \Exception
     */
    public static function getDateByInterval($date = null, $format = self::FORMAT, $intervalType = null, $intervalValue = null)
    {
        $dateTime = new DateTime($date);
        $dateTime->setTimezone(new DateTimeZone('UTC'));
        $interval = new DateInterval($intervalValue);
        if ($intervalType == self::INTERVAL_TYPE_ADD) {
            $dateTime->add($interval);
        }
        if ($intervalType == self::INTERVAL_TYPE_SUB) {
            $dateTime->sub($interval);
        }

        return $dateTime->format($format);
    }

    /**
     * Возвращает дату по указанным параметрам
     *
     * @param null $date Дата
     * @param string $format Формат даты
     * @param string $timeZone Временная зона даты
     *
     * @return string
     * @throws \Exception
     */
    public static function getDate($date = null, $format = self::FORMAT, $timeZone = 'UTC')
    {
        $dateTime = new DateTime($date);
        if (!is_null($timeZone)) {
            $dateTime->setTimezone(new DateTimeZone($timeZone));
        }

        return $dateTime->format($format);
    }
}
